
/**
 * -----------------------------------------------------
 * Section is a behavior for sections.
 * A section is a visual that is intended to fit itself
 * into a pane of a presentation.
 * It may have a div element which needs to have Menu
 * behavior installed.
 *
 * Logging of Section.installOn() events can be turned
 * on by setting Log.enabled to true and setting either
 * Section.debug.installOn or Behavior.debug.installOn
 * to true.
 */
new Behavior({
  name: "Section",
  /**
   * Section.installOn(element, pane) installs Section
   * behavior on element.
   */
  init: function(element, pane) {
    element.NAME = element.IDENTIFIER;
    Visual.installOn(element);
    var title = element.title;
    if (element.className == "error") {
      pane.SET_VISUAL(element);
      return;
    }
    element.className = "content";
    var frame = pane.SET_CONTENT(element);
    var menuList = [];
    var childList = element.childNodes;
    for (var i = 0; i < childList.length; i++) {
      var child = childList.item(i);
      if (child.className && child.className.match(/^menu/)) {
        menuList.push(child);
      }
    }
    if (!frame) {
      frame = new Frame(pane);
    }
    if (menuList.length == 0) {
      frame.setVisual(element);
      return;
    }
    frame.title = title;
    for (var j = 0; j < menuList.length; j++) {
      var menu = menuList[j];
      if (element.MENU) {
        var message = DOM.createElement("h4", "Extra Menu");
        message.className = "error-text"
        DOM.insertFirst(menu, message, "Section.init")
        menu.className = "error";
      } else {
        element.MENU = menu;
        Menu.installOn(menu, element, frame);
      }
    }
  },
  members: {
    toString: function() {
      return "Section<" + this.NAME + ">";
    }
  }
});
