
/**
 * -----------------------------------------------------
 * Section is a behavior for sections.
 * A section is a visual that is intended to fit itself
 * into the content pane of a presentation.
 * It may have a div element which needs to have Menu
 * behavior installed.
 *
 * Logging of Section.installOn() events can be turned
 * on by setting Section.debug.installOn to true.
 */
new Behavior({
  name: "Section",
  /**
   * Section.installOn(element, pane) installs Section
   * behavior on element.
   */
  init: function(element, pane) {
    element.NAME = element.IDENTIFIER;
    if (element.title) {
      var header = DOM.createElement("h4", element.title);
      DOM.insertFirst(element, header, "Section.init");
    }
    var menuList = [];
    var putList = [];
    if (element.className != "error") {
      element.className = "content";
      var subdivList = element.getElementsByTagName("div");
      for (var i = 0; i < subdivList.length; i++) {
        var subdiv = subdivList.item(i);
        if (subdiv.className.match(/^menu/)) {
          menuList.push(subdiv);
        } else if (subdiv.className.match(/^put-/)) {
          putList.push(subdiv);
        }
      }
    }
    Visual.installOn(element);
    pane.SET_VISUAL(element);
    if (menuList.length == 0 && putList.length == 0) {
      return;
    }
    var frame = new Frame(pane);
    for (var k = 0; k < putList.length; k++) {
      var putItem = putList[k];
      var putClass = putItem.className;
      putItem.className += " content";
      Visual.installOn(putItem);
      var width = putItem.CLEAR_WIDTH() || "50%";
      var height = putItem.CLEAR_HEIGHT() || "50%";
      if (putClass == "put-left") {
        frame.putLeft(putItem, width);
      } else if (putClass == "put-right") {
        frame.putRight(putItem, width);
      } else if (putClass == "put-top") {
        frame.putTop(putItem, height);
      } else if (putClass == "put-bottom") {
        frame.putBottom(putItem, height);
      } else {
        var message = DOM.createElement("h4", "Invalid Put Type: " + putClass);
        message.className = "error-text"
        DOM.insertFirst(putItem, message, "Section.init")
        frame.putTop(putItem, height);
      }
    }
    if (menuList.length == 0) {
      frame.setVisual(element);
    }
    for (var j = 0; j < menuList.length; j++) {
      var menu = menuList[j];
      if (element.MENU) {
        message = DOM.createElement("h4", "Extra Menu");
        message.className = "error-text"
        DOM.insertFirst(menu, message, "Section.init")
        menu.className = "error";
      } else {
        element.MENU = menu;
        Menu.installOn(menu, element, frame);
      }
    }
  },
  members: {
    toString: function() {
      return "Section<" + this.NAME + ">";
    }
  }
});
